==> Flask-JSONRPC-3.0.0.tar.gz: Flask-JSONRPC-3.0.0/tests/unit/conftest.py <==
# Copyright (c) 2012-2022, Cenobit Technologies, Inc. http://cenobit.es/
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# * Neither the name of the Cenobit Technologies nor the names of
#    its contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
import pytest

from ..test_apps.app import create_app
from ..test_apps.async_app import create_async_app


@pytest.fixture(scope='module')
def app():
    """Create and configure a new app instance for each test."""
    flask_app = create_app({'TESTING': True})

    yield flask_app


@pytest.fixture(scope='module')
def async_app():
    """Create and configure a new async app instance for each test."""
    flask_app = create_async_app({'TESTING': True})

    yield flask_app


# pylint: disable=W0621
@pytest.fixture(scope='module')
def client(app):
    """A test client for the app."""
    return app.test_client()


# pylint: disable=W0621
@pytest.fixture(scope='module')
def async_client(async_app):
    """A test async client for the app."""
    with async_app.test_client() as testing_client:
        yield testing_client


# pylint: disable=W0621
@pytest.fixture
def runner(app):
    """A test runner for the app's Click commands."""
    return app.test_cli_runner()

==> Flask-JSONRPC-3.0.1.tar.gz: Flask-JSONRPC-3.0.1/tests/unit/conftest.py <==
# Copyright (c) 2012-2022, Cenobit Technologies, Inc. http://cenobit.es/
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# * Neither the name of the Cenobit Technologies nor the names of
#    its contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
import typing as t

import pytest

from ..test_apps.app import create_app
from ..test_apps.async_app import create_async_app

# Python 3.11+
try:
    from typing import Self
except ImportError:  # pragma: no cover
    from typing_extensions import Self  # noqa: F401

if t.TYPE_CHECKING:
    from flask import Flask
    from flask.testing import FlaskClient, FlaskCliRunner


@pytest.fixture(scope='module')
def app() -> 't.Generator[Flask]':
    """Create and configure a new app instance for each test."""
    flask_app = create_app({'TESTING': True})

    yield flask_app


@pytest.fixture(scope='module')
def async_app() -> 't.Generator[Flask]':
    """Create and configure a new async app instance for each test."""
    flask_app = create_async_app({'TESTING': True})

    yield flask_app


# pylint: disable=W0621
@pytest.fixture(scope='module')
def client(app: 'Flask') -> 'FlaskClient':
    """A test client for the app."""
    return app.test_client()


# pylint: disable=W0621
@pytest.fixture(scope='module')
def async_client(async_app: 'Flask') -> 't.Generator[FlaskClient]':
    """A test async client for the app."""
    with async_app.test_client() as testing_client:
        yield testing_client


# pylint: disable=W0621
@pytest.fixture
def runner(app: 'Flask') -> 'FlaskCliRunner':
    """A test runner for the app's Click commands."""
    return app.test_cli_runner()
